| Title: | What the Package Does (One Line, Title Case) |
|---|---|
| Description: | What the package does (one paragraph). |
| Authors: | First Last [aut, cre] (ORCID: YOUR-ORCID-ID) |
| Maintainer: | First Last <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.0.9000 |
| Built: | 2026-05-28 10:12:49 UTC |
| Source: | https://github.com/hypertidy/xplot |
Work around core funs being bound to assumptions, we just want points, lines, rects, segments, text, when we want it. :)
xplot(x, y = NULL, ..., add = FALSE, type = "p")xplot(x, y = NULL, ..., add = FALSE, type = "p")
x, y
|
the |
... |
other graphical parameters (see |
type |
1-character string giving the type of plot desired. The
following values are possible, for details, see |
nothing, called for side effect (creating or drawing on a plot)
xplot(1:10, 10:1, type = "b") xplot(rnorm(10), rnorm(10), type = "b", add = T) xrect(runif(36), runif(36), add = FALSE)xplot(1:10, 10:1, type = "b") xplot(rnorm(10), rnorm(10), type = "b", add = T) xrect(runif(36), runif(36), add = FALSE)